r9845 - helma/helma/trunk/src/helma/objectmodel/db

[email protected] Thu, 30 Jul 2009 11:04:43 +0200 (CEST)
Newsgroups gmane.comp.java.helma.cvs
Message-ID <20090730090443.BB1313D0E3@mia>
Author: hannes
Date: 2009-07-30 11:04:43 +0200 (Thu, 30 Jul 2009)
New Revision: 9845

Modified:
   helma/helma/trunk/src/helma/objectmodel/db/Node.java
Log:
Evict primary key in deepRemoveNode(). Fixes bug 668 by making sure removed group nodes are not cached.

Details at http://dev.helma.org/trac/helma/changeset/9845

Modified: helma/helma/trunk/src/helma/objectmodel/db/Node.java
===================================================================
--- helma/helma/trunk/src/helma/objectmodel/db/Node.java	2009-07-29 15:45:07 UTC (rev 9844)
+++ helma/helma/trunk/src/helma/objectmodel/db/Node.java	2009-07-30 09:04:43 UTC (rev 9845)
@@ -1434,8 +1434,11 @@
             }
         }
 
         // mark the node as deleted
         setParent(null);
+        if (primaryKey != null || state != TRANSIENT) {
+            nmgr.evictKey(getKey());
+        }
         markAs(DELETED);
     }
@@ -1434,8 +1434,11 @@
         }
 
-        // mark the node as deleted
+        // mark the node as deleted and evict its primary key
         setParent(null);